# also update debian/changelog
DOCRELEASE=5.2

DGDIR?=/usr/share/pmg-doc-generator

ASCIIDOC_PMG?=/usr/bin/asciidoc-pmg

PERL_DOC_ENV=PMG_GENERATING_DOCS=1

PMG_COMMON_DOC_SOURCES=                 \
	${ASCIIDOC_PMG}			\
	pmg-copyright.adoc              \
	docinfo.xml

all:

pmgsh.1-synopsis.adoc:
	@echo 'Interactive session:' >$@.tmp
	@echo '' >>$@.tmp
	@echo '*pmgsh*' >>$@.tmp
	@echo '' >>$@.tmp
	@echo 'Directly call API functions:' >>$@.tmp
	@echo '' >>$@.tmp
	@echo '*pmgsh* `(get|set|create|help)` `<path>` `[OPTIONS]`' >>$@.tmp
	mv $@.tmp $@

pmg-smtp-filter.8-synopsis.adoc:
	@echo 'Please use systemd tools to manage this service.' >$@.tmp
	@echo '' >>$@.tmp
	@echo '*systemctl* `(start|stop|restart|reload|status)` `pmg-smtp-filter`' >>$@.tmp
	mv $@.tmp $@

pmgpolicy.8-synopsis.adoc:
	@echo 'Please use systemd tools to manage this service.' >$@.tmp
	@echo '' >>$@.tmp
	@echo '*systemctl* `(start|stop|restart|reload|status)` `pmgpolicy`' >>$@.tmp
	mv $@.tmp $@

docinfo.xml:
	cp ${DGDIR}/$@ $@.tmp
	mv $@.tmp $@

%-opts.adoc: ${DGDIR}/gen-%-opts.pl
	$(PERL_DOC_ENV) perl -I. ${DGDIR}/gen-$*-opts.pl >$@.tmp
	mv $@.tmp $@

pmg.%-conf-opts.adoc: ${DGDIR}/gen-pmg.conf.5-opts.pl
	$(PERL_DOC_ENV) perl -I. ${DGDIR}/gen-pmg.conf.5-opts.pl $* >$@.tmp
	mv $@.tmp $@

%.adoc: ${DGDIR}/gen-%-adoc.pl
	$(PERL_DOC_ENV) perl -I. ${DGDIR}/gen-$*-adoc.pl >$@.tmp
	mv $@.tmp $@

%.1-synopsis.adoc:
	$(PERL_DOC_ENV) perl -I. -e "use PMG::CLI::$(subst -,_,$*);print PMG::CLI::$(subst -,_,$*)->generate_asciidoc_synopsis();" > $@.tmp
	mv $@.tmp $@

%.8-synopsis.adoc:
	$(PERL_DOC_ENV) perl -I. -e "use PMG::Service::$(subst -,_,$*);print PMG::Service::$(subst -,_,$*)->generate_asciidoc_synopsis();" > $@.tmp
	mv $@.tmp $@

ifneq (${DGDIR},.)
%.adoc: ${DGDIR}/%.adoc
	cp $< $@.tmp
	mv $@.tmp $@
endif


%-plain.html: %.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-wiki -o $@ $*.adoc

chapter-%.html: %.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-chapter -o $@ $*.adoc

%.1: %.adoc %.1-synopsis.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-man -o $@ $*.adoc
	test -n "$${NOVIEW}" || man -l $@

%.1.html: %.adoc %.1-synopsis.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-man-html -o $@ $*.adoc

%.8: %.adoc %.8-synopsis.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-man -o $@ $*.adoc
	test -n "$${NOVIEW}" || man -l $@

%.8.html: %.adoc %.8-synopsis.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-man-html -o $@ $*.adoc

%.5: %.adoc %.5-opts.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-man -o $@ $*.adoc
	test -n "$${NOVIEW}" || man -l $@

%.5.html: %.adoc %.5-opts.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-man-html -o $@ $*.adoc

%.5-plain.html: %.adoc %.5-opts.adoc ${PMG_COMMON_DOC_SOURCES}
	${ASCIIDOC_PMG} compile-man-wiki -o $@ $*.adoc


.PHONY: cleanup-docgen
cleanup-docgen:
	rm -f *.xml.tmp *.1 *.5 *.8 *.adoc docinfo.xml

CHAPTER_LIST = \
	chapter-pmg-bibliography.html \
	chapter-pmgbackup.html \
	chapter-pmgcm.html \
	chapter-pmgconfig.html \
	chapter-pmgdb.html \
	chapter-pmgperf.html \
	chapter-pmgqm.html \
	chapter-pmgreport.html \
	chapter-pmgsh.html \
	chapter-pmgupgrade.html \
	chapter-pmgversion.html \
	pmg-admin-guide.html

CLUSTER_CONF_ADOCDEPENDS = \
	${CLUSTER_CONF_ADOCSOURCES} \
	cluster.conf.5-opts.adoc

CLUSTER_CONF_ADOCSOURCES = \
	cluster.conf.adoc \
	pmg-copyright.adoc

INDEX_ADOCDEPENDS = \
	${INDEX_ADOCSOURCES}

INDEX_ADOCSOURCES = \
	index.adoc \
	man1-index-table.adoc \
	man5-index-table.adoc \
	man8-index-table.adoc

LDAP_CONF_ADOCDEPENDS = \
	${LDAP_CONF_ADOCSOURCES} \
	ldap.conf.5-opts.adoc

LDAP_CONF_ADOCSOURCES = \
	ldap.conf.adoc \
	pmg-copyright.adoc

MANUAL_PAGES = \
	cluster.conf.5 \
	ldap.conf.5 \
	pmg-smtp-filter.8 \
	pmg.conf.5 \
	pmgbackup.1 \
	pmgcm.1 \
	pmgconfig.1 \
	pmgdaemon.8 \
	pmgdb.1 \
	pmgmirror.8 \
	pmgperf.1 \
	pmgpolicy.8 \
	pmgproxy.8 \
	pmgqm.1 \
	pmgreport.1 \
	pmgsh.1 \
	pmgsubscription.1 \
	pmgtunnel.8 \
	pmgupgrade.1 \
	pmgversion.1 \
	user.conf.5

MANUAL_SOURCES = \
	cluster.conf.adoc \
	ldap.conf.adoc \
	pmg-copyright.adoc \
	pmg-smtp-filter.adoc \
	pmg.conf.adoc \
	pmgbackup.adoc \
	pmgcm.adoc \
	pmgconfig.adoc \
	pmgdaemon.adoc \
	pmgdb.adoc \
	pmgmirror.adoc \
	pmgperf.adoc \
	pmgpolicy.adoc \
	pmgproxy.adoc \
	pmgqm.adoc \
	pmgreport.adoc \
	pmgsh.adoc \
	pmgsubscription.adoc \
	pmgtunnel.adoc \
	pmgupgrade.adoc \
	pmgversion.adoc \
	user.conf.adoc

PMGBACKUP_ADOCDEPENDS = \
	${PMGBACKUP_ADOCSOURCES} \
	pmgbackup.1-synopsis.adoc

PMGBACKUP_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgbackup.adoc

PMGCM_ADOCDEPENDS = \
	${PMGCM_ADOCSOURCES} \
	pmgcm.1-synopsis.adoc

PMGCM_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgcm.adoc

PMGCONFIG_ADOCDEPENDS = \
	${PMGCONFIG_ADOCSOURCES} \
	fetchmail.conf.5-opts.adoc \
	pmg.admin-conf-opts.adoc \
	pmg.clamav-conf-opts.adoc \
	pmg.mail-options-conf-opts.adoc \
	pmg.mail-ports-conf-opts.adoc \
	pmg.mail-relaying-conf-opts.adoc \
	pmg.mail-tls-conf-opts.adoc \
	pmg.spam-conf-opts.adoc \
	pmg.spamquar-conf-opts.adoc \
	pmg.virusquar-conf-opts.adoc \
	pmgconfig.1-synopsis.adoc

PMGCONFIG_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgconfig.adoc

PMGDAEMON_ADOCDEPENDS = \
	${PMGDAEMON_ADOCSOURCES} \
	pmgdaemon.8-synopsis.adoc

PMGDAEMON_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgdaemon.adoc

PMGDB_ADOCDEPENDS = \
	${PMGDB_ADOCSOURCES} \
	pmgdb.1-synopsis.adoc

PMGDB_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgdb.adoc

PMGMIRROR_ADOCDEPENDS = \
	${PMGMIRROR_ADOCSOURCES} \
	pmgmirror.8-synopsis.adoc

PMGMIRROR_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgmirror.adoc

PMGPERF_ADOCDEPENDS = \
	${PMGPERF_ADOCSOURCES} \
	pmgperf.1-synopsis.adoc

PMGPERF_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgperf.adoc

PMGPOLICY_ADOCDEPENDS = \
	${PMGPOLICY_ADOCSOURCES} \
	pmgpolicy.8-synopsis.adoc

PMGPOLICY_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgpolicy.adoc

PMGPROXY_ADOCDEPENDS = \
	${PMGPROXY_ADOCSOURCES} \
	pmgproxy.8-synopsis.adoc

PMGPROXY_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgproxy.adoc

PMGQM_ADOCDEPENDS = \
	${PMGQM_ADOCSOURCES} \
	pmgqm.1-synopsis.adoc

PMGQM_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgqm.adoc

PMGREPORT_ADOCDEPENDS = \
	${PMGREPORT_ADOCSOURCES} \
	pmgreport.1-synopsis.adoc

PMGREPORT_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgreport.adoc

PMGSH_ADOCDEPENDS = \
	${PMGSH_ADOCSOURCES} \
	pmgsh.1-synopsis.adoc

PMGSH_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgsh.adoc

PMGSUBSCRIPTION_ADOCDEPENDS = \
	${PMGSUBSCRIPTION_ADOCSOURCES} \
	pmgsubscription.1-synopsis.adoc

PMGSUBSCRIPTION_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgsubscription.adoc

PMGTUNNEL_ADOCDEPENDS = \
	${PMGTUNNEL_ADOCSOURCES} \
	pmgtunnel.8-synopsis.adoc

PMGTUNNEL_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgtunnel.adoc

PMGUPGRADE_ADOCDEPENDS = \
	${PMGUPGRADE_ADOCSOURCES} \
	pmgupgrade.1-synopsis.adoc

PMGUPGRADE_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgupgrade.adoc

PMGVERSION_ADOCDEPENDS = \
	${PMGVERSION_ADOCSOURCES} \
	pmgversion.1-synopsis.adoc

PMGVERSION_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmgversion.adoc

PMG_ADMIN_GUIDE_ADOCDEPENDS = \
	${PMG_ADMIN_GUIDE_ADOCSOURCES} \
	cluster.conf.5-opts.adoc \
	fetchmail.conf.5-opts.adoc \
	ldap.conf.5-opts.adoc \
	pmg-smtp-filter.8-synopsis.adoc \
	pmg.admin-conf-opts.adoc \
	pmg.clamav-conf-opts.adoc \
	pmg.conf.5-opts.adoc \
	pmg.mail-options-conf-opts.adoc \
	pmg.mail-ports-conf-opts.adoc \
	pmg.mail-relaying-conf-opts.adoc \
	pmg.mail-tls-conf-opts.adoc \
	pmg.spam-conf-opts.adoc \
	pmg.spamquar-conf-opts.adoc \
	pmg.virusquar-conf-opts.adoc \
	pmgbackup.1-synopsis.adoc \
	pmgcm.1-synopsis.adoc \
	pmgconfig.1-synopsis.adoc \
	pmgdaemon.8-synopsis.adoc \
	pmgdb.1-synopsis.adoc \
	pmgmirror.8-synopsis.adoc \
	pmgperf.1-synopsis.adoc \
	pmgpolicy.8-synopsis.adoc \
	pmgproxy.8-synopsis.adoc \
	pmgsh.1-synopsis.adoc \
	pmgtunnel.8-synopsis.adoc \
	user.conf.5-opts.adoc

PMG_ADMIN_GUIDE_ADOCSOURCES = \
	GFDL.adoc \
	cluster.conf.adoc \
	getting-help.adoc \
	ldap.conf.adoc \
	nmap.adoc \
	pmg-admin-guide.adoc \
	pmg-administration.adoc \
	pmg-bibliography.adoc \
	pmg-installation.adoc \
	pmg-intro.adoc \
	pmg-mail-filter.adoc \
	pmg-planning-deployment.adoc \
	pmg-rule-macros.adoc \
	pmg-smtp-filter.adoc \
	pmg-ssl-certificate.adoc \
	pmg-usbstick.adoc \
	pmg.conf.adoc \
	pmgbackup.adoc \
	pmgcm.adoc \
	pmgconfig.adoc \
	pmgdaemon.adoc \
	pmgdb.adoc \
	pmgmirror.adoc \
	pmgperf.adoc \
	pmgpolicy.adoc \
	pmgproxy.adoc \
	pmgqm.adoc \
	pmgreport.adoc \
	pmgsh.adoc \
	pmgsubscription.adoc \
	pmgtunnel.adoc \
	pmgupgrade.adoc \
	pmgversion.adoc \
	user.conf.adoc

PMG_CONF_ADOCDEPENDS = \
	${PMG_CONF_ADOCSOURCES} \
	pmg.conf.5-opts.adoc

PMG_CONF_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmg.conf.adoc

PMG_INSTALLATION_ADOCDEPENDS = \
	${PMG_INSTALLATION_ADOCSOURCES}

PMG_INSTALLATION_ADOCSOURCES = \
	pmg-installation.adoc \
	pmg-usbstick.adoc

PMG_INTRO_ADOCDEPENDS = \
	${PMG_INTRO_ADOCSOURCES}

PMG_INTRO_ADOCSOURCES = \
	getting-help.adoc \
	pmg-intro.adoc

PMG_SMTP_FILTER_ADOCDEPENDS = \
	${PMG_SMTP_FILTER_ADOCSOURCES} \
	pmg-smtp-filter.8-synopsis.adoc

PMG_SMTP_FILTER_ADOCSOURCES = \
	pmg-copyright.adoc \
	pmg-smtp-filter.adoc

USER_CONF_ADOCDEPENDS = \
	${USER_CONF_ADOCSOURCES} \
	user.conf.5-opts.adoc

USER_CONF_ADOCSOURCES = \
	pmg-copyright.adoc \
	user.conf.adoc

WIKI_IMPORTS = \
	cluster.conf.5-plain.html \
	getting-help-plain.html \
	pmg-bibliography-plain.html \
	pmg.conf.5-plain.html \
	pmgbackup-plain.html \
	pmgcm-plain.html \
	pmgconfig-plain.html \
	pmgdb-plain.html \
	pmgperf-plain.html \
	pmgqm-plain.html \
	pmgreport-plain.html \
	pmgsh-plain.html \
	pmgupgrade-plain.html \
	pmgversion-plain.html

chapter-pmgbackup.html: ${PMGBACKUP_ADOCDEPENDS}

chapter-pmgcm.html: ${PMGCM_ADOCDEPENDS}

chapter-pmgconfig.html: ${PMGCONFIG_ADOCDEPENDS}

chapter-pmgdb.html: ${PMGDB_ADOCDEPENDS}

chapter-pmgperf.html: ${PMGPERF_ADOCDEPENDS}

chapter-pmgqm.html: ${PMGQM_ADOCDEPENDS}

chapter-pmgreport.html: ${PMGREPORT_ADOCDEPENDS}

chapter-pmgsh.html: ${PMGSH_ADOCDEPENDS}

chapter-pmgupgrade.html: ${PMGUPGRADE_ADOCDEPENDS}

chapter-pmgversion.html: ${PMGVERSION_ADOCDEPENDS}

cluster.conf.5: ${CLUSTER_CONF_ADOCDEPENDS}

cluster.conf.5-plain.html: ${CLUSTER_CONF_ADOCDEPENDS}

cluster.conf.5.html: ${CLUSTER_CONF_ADOCDEPENDS}

ldap.conf.5: ${LDAP_CONF_ADOCDEPENDS}

ldap.conf.5-plain.html: ${LDAP_CONF_ADOCDEPENDS}

ldap.conf.5.html: ${LDAP_CONF_ADOCDEPENDS}

pmg-admin-guide.html: ${PMG_ADMIN_GUIDE_ADOCDEPENDS}

pmg-smtp-filter.8: ${PMG_SMTP_FILTER_ADOCDEPENDS}

pmg-smtp-filter.8-plain.html: ${PMG_SMTP_FILTER_ADOCDEPENDS}

pmg-smtp-filter.8.html: ${PMG_SMTP_FILTER_ADOCDEPENDS}

pmg.conf.5: ${PMG_CONF_ADOCDEPENDS}

pmg.conf.5-plain.html: ${PMG_CONF_ADOCDEPENDS}

pmg.conf.5.html: ${PMG_CONF_ADOCDEPENDS}

pmgbackup-plain.html: ${PMGBACKUP_ADOCDEPENDS}

pmgbackup.1: ${PMGBACKUP_ADOCDEPENDS}

pmgbackup.1-plain.html: ${PMGBACKUP_ADOCDEPENDS}

pmgbackup.1.html: ${PMGBACKUP_ADOCDEPENDS}

pmgcm-plain.html: ${PMGCM_ADOCDEPENDS}

pmgcm.1: ${PMGCM_ADOCDEPENDS}

pmgcm.1-plain.html: ${PMGCM_ADOCDEPENDS}

pmgcm.1.html: ${PMGCM_ADOCDEPENDS}

pmgconfig-plain.html: ${PMGCONFIG_ADOCDEPENDS}

pmgconfig.1: ${PMGCONFIG_ADOCDEPENDS}

pmgconfig.1-plain.html: ${PMGCONFIG_ADOCDEPENDS}

pmgconfig.1.html: ${PMGCONFIG_ADOCDEPENDS}

pmgdaemon.8: ${PMGDAEMON_ADOCDEPENDS}

pmgdaemon.8-plain.html: ${PMGDAEMON_ADOCDEPENDS}

pmgdaemon.8.html: ${PMGDAEMON_ADOCDEPENDS}

pmgdb-plain.html: ${PMGDB_ADOCDEPENDS}

pmgdb.1: ${PMGDB_ADOCDEPENDS}

pmgdb.1-plain.html: ${PMGDB_ADOCDEPENDS}

pmgdb.1.html: ${PMGDB_ADOCDEPENDS}

pmgmirror.8: ${PMGMIRROR_ADOCDEPENDS}

pmgmirror.8-plain.html: ${PMGMIRROR_ADOCDEPENDS}

pmgmirror.8.html: ${PMGMIRROR_ADOCDEPENDS}

pmgperf-plain.html: ${PMGPERF_ADOCDEPENDS}

pmgperf.1: ${PMGPERF_ADOCDEPENDS}

pmgperf.1-plain.html: ${PMGPERF_ADOCDEPENDS}

pmgperf.1.html: ${PMGPERF_ADOCDEPENDS}

pmgpolicy.8: ${PMGPOLICY_ADOCDEPENDS}

pmgpolicy.8-plain.html: ${PMGPOLICY_ADOCDEPENDS}

pmgpolicy.8.html: ${PMGPOLICY_ADOCDEPENDS}

pmgproxy.8: ${PMGPROXY_ADOCDEPENDS}

pmgproxy.8-plain.html: ${PMGPROXY_ADOCDEPENDS}

pmgproxy.8.html: ${PMGPROXY_ADOCDEPENDS}

pmgqm-plain.html: ${PMGQM_ADOCDEPENDS}

pmgqm.1: ${PMGQM_ADOCDEPENDS}

pmgqm.1-plain.html: ${PMGQM_ADOCDEPENDS}

pmgqm.1.html: ${PMGQM_ADOCDEPENDS}

pmgreport-plain.html: ${PMGREPORT_ADOCDEPENDS}

pmgreport.1: ${PMGREPORT_ADOCDEPENDS}

pmgreport.1-plain.html: ${PMGREPORT_ADOCDEPENDS}

pmgreport.1.html: ${PMGREPORT_ADOCDEPENDS}

pmgsh-plain.html: ${PMGSH_ADOCDEPENDS}

pmgsh.1: ${PMGSH_ADOCDEPENDS}

pmgsh.1-plain.html: ${PMGSH_ADOCDEPENDS}

pmgsh.1.html: ${PMGSH_ADOCDEPENDS}

pmgsubscription.1: ${PMGSUBSCRIPTION_ADOCDEPENDS}

pmgsubscription.1-plain.html: ${PMGSUBSCRIPTION_ADOCDEPENDS}

pmgsubscription.1.html: ${PMGSUBSCRIPTION_ADOCDEPENDS}

pmgtunnel.8: ${PMGTUNNEL_ADOCDEPENDS}

pmgtunnel.8-plain.html: ${PMGTUNNEL_ADOCDEPENDS}

pmgtunnel.8.html: ${PMGTUNNEL_ADOCDEPENDS}

pmgupgrade-plain.html: ${PMGUPGRADE_ADOCDEPENDS}

pmgupgrade.1: ${PMGUPGRADE_ADOCDEPENDS}

pmgupgrade.1-plain.html: ${PMGUPGRADE_ADOCDEPENDS}

pmgupgrade.1.html: ${PMGUPGRADE_ADOCDEPENDS}

pmgversion-plain.html: ${PMGVERSION_ADOCDEPENDS}

pmgversion.1: ${PMGVERSION_ADOCDEPENDS}

pmgversion.1-plain.html: ${PMGVERSION_ADOCDEPENDS}

pmgversion.1.html: ${PMGVERSION_ADOCDEPENDS}

user.conf.5: ${USER_CONF_ADOCDEPENDS}

user.conf.5-plain.html: ${USER_CONF_ADOCDEPENDS}

user.conf.5.html: ${USER_CONF_ADOCDEPENDS}

